Header

Struct Header 

pub struct Header {
Show 20 fields pub parent_hash: B256, pub ommers_hash: B256, pub beneficiary: Address, pub state_root: B256, pub transactions_root: B256, pub receipts_root: B256, pub withdrawals_root: Option<B256>, pub logs_bloom: Bloom, pub difficulty: U256, pub number: BlockNumber, pub gas_limit: u64, pub gas_used: u64, pub timestamp: u64, pub mix_hash: B256, pub nonce: u64, pub base_fee_per_gas: Option<u64>, pub blob_gas_used: Option<u64>, pub excess_blob_gas: Option<u64>, pub parent_beacon_block_root: Option<B256>, pub extra_data: Bytes,
}

Fields

parent_hash: B256

The Keccak 256-bit hash of the parent block’s header, in its entirety; formally Hp.

ommers_hash: B256

The Keccak 256-bit hash of the ommers list portion of this block; formally Ho.

beneficiary: Address

The 160-bit address to which all fees collected from the successful mining of this block be transferred; formally Hc.

state_root: B256

The Keccak 256-bit hash of the root node of the state trie, after all transactions are executed and finalisations applied; formally Hr.

transactions_root: B256

The Keccak 256-bit hash of the root node of the trie structure populated with each transaction in the transactions list portion of the block; formally Ht.

receipts_root: B256

The Keccak 256-bit hash of the root node of the trie structure populated with the receipts of each transaction in the transactions list portion of the block; formally He.

withdrawals_root: Option<B256>

The Keccak 256-bit hash of the withdrawals list portion of this block. https://eips.ethereum.org/EIPS/eip-4895

logs_bloom: Bloom

The Bloom filter composed from indexable information (logger address and log topics) contained in each log entry from the receipt of each transaction in the transactions list; formally Hb.

difficulty: U256

A scalar value corresponding to the difficulty level of this block. This can be calculated from the previous block’s difficulty level and the timestamp; formally Hd.

number: BlockNumber

A scalar value equal to the number of ancestor blocks. The genesis block has a number of zero; formally Hi.

gas_limit: u64

A scalar value equal to the current limit of gas expenditure per block; formally Hl.

gas_used: u64

A scalar value equal to the total gas used in transactions in this block; formally Hg.

timestamp: u64

A scalar value equal to the reasonable output of Unix’s time() at this block’s inception; formally Hs.

mix_hash: B256

A 256-bit hash which, combined with the nonce, proves that a sufficient amount of computation has been carried out on this block; formally Hm.

nonce: u64

A 64-bit value which, combined with the mixhash, proves that a sufficient amount of computation has been carried out on this block; formally Hn.

base_fee_per_gas: Option<u64>

A scalar representing EIP1559 base fee which can move up or down each block according to a formula which is a function of gas used in parent block and gas target (block gas limit divided by elasticity multiplier) of parent block. The algorithm results in the base fee per gas increasing when blocks are above the gas target, and decreasing when blocks are below the gas target. The base fee per gas is burned.

blob_gas_used: Option<u64>

The total amount of blob gas consumed by the transactions within the block, added in EIP-4844.

excess_blob_gas: Option<u64>

A running total of blob gas consumed in excess of the target, prior to the block. Blocks with above-target blob gas consumption increase this value, blocks with below-target blob gas consumption decrease it (bounded at 0). This was added in EIP-4844.

parent_beacon_block_root: Option<B256>

The hash of the parent beacon block’s root is included in execution blocks, as proposed by EIP-4788.

This enables trust-minimized access to consensus state, supporting staking pools, bridges, and more.

The beacon roots contract handles root storage, enhancing Ethereum’s functionalities.

extra_data: Bytes

An arbitrary byte array containing data relevant to this block. This must be 32 bytes or fewer; formally Hx.

Implementations

Source

impl Header

pub fn hash_slow(&self) -> B256

Heavy function that will calculate hash of data and will not save the change to metadata. Use [Header::seal], [SealedHeader] and unlock if you need hash to be persistent.

Source

impl Header

pub fn new( parent_hash: B256, ommers_hash: B256, beneficiary: Address, state_root: B256, transactions_root: B256, receipts_root: B256, logs_bloom: Bloom, difficulty: U256, number: u64, gas_limit: u64, gas_used: u64, timestamp: u64, extra_data: Bytes, mix_hash: B256, nonce: u64, base_fee_per_gas: Option<u64>, withdrawals_root: Option<B256>, blob_gas_used: Option<u64>, excess_blob_gas: Option<u64>, parent_beacon_block_root: Option<B256>, ) -> Self

pub fn rlp_encode(&self) -> Vec<u8>

pub fn rlp_decode(rlp: &[u8]) -> Self

pub fn get_block_hash(&self) -> String