Module task

Module task 

Task is a unit of work that can be executed by the processor/pre-processor.

Modules

datalake
module
Module is the unit of pre-processing. It contains the hash and the input. This is request interface for the preprocessor.

Structs

ExtendedModule

Enums

TaskEnvelope
TaskEnvelope is a structure that contains task itself This structure is used to provide the task to the pre-processor