Module processed_types
Source - account
- Processed account type
This contains the processed account type and its conversion to cairo format.
- block_proofs
- cairo_format
- This module contains the processed types for the Cairo format.
Used to serialize the processed types to the Cairo Program’s input format.
- datalake_compute
- header
- mmr
- module
- mpt
- query
- receipt
- This module defines the
ProcessedReceipt struct and its corresponding ProcessedReceiptInFelts struct. - storage
- This module defines the
ProcessedStorage struct and its corresponding ProcessedStorageInFelts struct. - task
- transaction
- The transaction module contains the ProcessedTransaction struct and its conversion to ProcessedTransactionInFelts.
- uint256
- This module contains the
Uint256 type, which is a 256-bit unsigned integer.
This is compatible with Cairo uint256 type.